@@ -11,9 +11,11 @@ from octohot.cli.regex.colored_texts import Colors
 @click.argument('origin_branch')
 def pr(pr_title, pr_comment, branch_name, default_branch, origin_branch):
     from octohot.cli.config import repositories
+    from octohot.cli.github.utils import login
+    github_login = login()
     for repo in repositories:
         if repo.is_github() and repo.is_current_branch(branch_name):
-            _pr(repo, pr_title, pr_comment, branch_name, default_branch, origin_branch)
+            _pr(github_login, repo, pr_title, pr_comment, branch_name, default_branch, origin_branch)
 
 
 def _pr(github_login, repo, pr_title, pr_comment, branch_name, default_branch, origin_branch):
